==> IceWarpServer-9.1.0_RHEL5.tar.gz: html/mail/inc/function.login.php <==
<?php

function dolog($user,$log)
{
  global $lang,$otherconfig;

  if(!$user) return 0;
  if($otherconfig['LOGGINGPATH'])
  {
    if(!ereg("/$",$otherconfig['LOGGINGPATH']) && !ereg("\\$",$otherconfig['LOGGINGPATH'])) $otherconfig['LOGGINGPATH'].="/";
    $path=$otherconfig['LOGGINGPATH'];
  }
  else $path=loggingpath;

  if(!$path) return false;
  mkdirtree($path);
  $file= @fopen ($path.date("Ymd").".log", "ab");
  @fputs($file,date("r")." ".$_SERVER[REMOTE_ADDR]." ".sprintf($lang["LOG_$log"],$user)."\r\n");
  @fclose($file);

  return true;
}

function checkuid($uid)
{
  if(time()>substr($uid,13)+uidtimeout) return 0;
  return 1;
}
//date 1.2.2006
function loginuser($user, $password,$method="",$uid="")
{
    global $admin, $integrate, $domain, $mailserver, $dleavemessages, $otherconfig, $LOCAL_ADDR, $REMOTE_ADDR,$pass_expired;

    if (!$user) return false;

    if ($otherconfig["FULLMERAK"])
    {
      list($fdummy, $username) = explode("/", $user);
      if ($username) $user = $username;

     @include_once('integrateinclude.html');
     @include_once('../integrateinclude.html');

      $result = integrateauthenticateuser($user, $password, $method, $uid);

      if (substr($result, 0, 1) == "*")
      {
        $result = trim(substr($result, 1, strlen($result) - 1));
        $merakadmin = substr($result, 0, 1);
        $result = trim(substr($result, 1, strlen($result) - 1));

        list($merakname, $merakemail) = explode("<", $result);
        $merakname = trim($merakname);
        list($merakemail, $merakpath) = explode(">", $merakemail);
        $merakemail = trim($merakemail);
        $merakpath  = trim($merakpath);

        if (strpos($merakpath, "\n"))
        {
          $items = explode("\n", $merakpath);
          $merakpath = trim($items[0]);
          $userquota = trim($items[1]);
          $ntpassword = trim($items[3]);
          if (!$ntpassword) $password = trim($items[2]);
          $pass_expired = trim($items[4]);
        }

		if (!$merakpath || strpos($merakpath,'|') === 0) return false;

        list($xalias, $merakdomain) = explode("@", $merakemail);
        list($xdomain) = explode(";", $domain);

        if (strcasecmp($xdomain, $merakdomain)) $user = $merakdomain . "/" . $user;

        if (trim($otherconfig["ALLOWEDDOMAINS"]))
        {
          if (!(strpos(";;" . strtolower(trim($otherconfig["ALLOWEDDOMAINS"])) . ";", ";" . strtolower($merakdomain) . ";"))) return false;
        }
      }
      else
        return false;
    }

    $config = getuserconfig($user);

    if (!$config)
    {
      if (!($integrate)) return false;

      $accounts = getaccounts();

      list($fdomain, $username) = explode("/", $user);
      if (!($username)) $username = $user;

      $config["USER"] = $user;
      $config["PASS"] = $password;
      $add = "";
      list($fdomain) = explode(";", $domain);
      if ($fdomain) if (!(strpos($user, "@"))) $add = "@" . $fdomain;
      $config["EMAIL"] = $username . $add;
      if ($merakemail) $config["EMAIL"] = $merakemail;
      $config["FULLNAME"] = $username;
      if ($merakname) $config["FULLNAME"] = $merakname;
      $config["ADMIN"] = false;
      if ($merakadmin) $config["ADMIN"] = $merakadmin;
      $config["HOST"] = $mailserver;
      $config["HOSTUSER"] = $user;
      $config["HOSTPASS"] = $password;
      $config["DELETE"] = !($dleavemessages);
      $config["REPLYTO"] = "";
      $config["FULLHEADER"] = "";
      $config["MULTI"] = "";
      $config["ATTACH"] = "";
      $config["DELETESERVER"] = $otherconfig["DELETEMESSAGES"];
      $config["UIDLDELETE"] = $otherconfig["DELETEDELETED"];
      $config["NOQUOTA"] = "";

      $accounts[] = $config;
      saveaccounts($accounts);
    }
    else{
      // NT Password - For Encrypted Login use old one
      if ($ntpassword && $method) $password = $config["PASS"];

      if ($integrate && ($config["PASS"] <> $password || $config["HOST"] <> $mailserver || $config["HOSTUSER"] <> $user || $config["HOSTPASS"] <> $password || $config["ADMIN"] <> $merakadmin || $config["FULLNAME"] <> $merakname))
      {

        $config["PASS"] = $password;
        $config["HOST"] = $mailserver;
        $config["HOSTUSER"] = $user;
        $config["HOSTPASS"] = $password;

        if ($otherconfig["FULLMERAK"])
        {
          // 2 - Does not inherit admin flag
          if ($config["ADMIN"] <> 2) $config["ADMIN"] = $merakadmin;
          $config["EMAIL"] = $merakemail;
          $config["FULLNAME"] = $merakname;
        }
        saveuserconfig($user, $config);
      }
    }

    $accounts = array();

    if (!$integrate && strcasecmp($config["PASS"], $password)) return false;

    // Session ID
    $id = md5(uniqid(""));

    // Session Directory
    @mkdir(sessiondir, 0750);
    $sessionpath = sessiondir . $id . "/";
    @mkdir($sessionpath, 0750);

    updatesession($id, $user);

    // Previous Session Delete
    $session = @file(usersdir . $user . "/" . sessionfile);
    if (is_array($session))
    {
      @unlink(sessiondir . trim($session[0]) . "/" . sessionfile);
      @rmdir(sessiondir . trim($session[0]));
    }

    // User Directory
    list($fdomain, $username) = explode("/", $user);
    @mkdir(usersdir, 0750);
    if ($username) @mkdir(usersdir . $fdomain, 0750);
    @mkdir(usersdir . $user, 0750);

    // Save Session To Users Dir For Future Delete
    @copy($sessionpath . sessionfile, usersdir . $user . "/" . sessionfile);

    if ($otherconfig["FULLMERAK"] && directmerak && $merakpath)
    {
      unset($calendarenabled,$imenabled);
      pluginsloadstate($config["EMAIL"],$calendarenabled,$imenabled);
      savemailboxpath($id, trim($merakpath), $userquota, $calendarenabled,$imenabled);
    }
    dolog($user,1);
    return $id;
}
?>

==> IceWarpServer-9.4.1_RHEL5.tar.gz: html/mail/inc/function.login.php <==
<?php

function dolog($user,$log)
{
  global $lang,$otherconfig;

  if(!$user) return 0;
  if($otherconfig['LOGGINGPATH'])
  {
    if(!ereg("/$",$otherconfig['LOGGINGPATH']) && !ereg("\\$",$otherconfig['LOGGINGPATH'])) $otherconfig['LOGGINGPATH'].="/";
    $path=$otherconfig['LOGGINGPATH'];
  }
  else $path=loggingpath;

  if(!$path) return false;
  mkdirtree($path);
  $file= @fopen ($path.date("Ymd").".log", "ab");
  @fputs($file,date("r")." ".$_SERVER[REMOTE_ADDR]." ".sprintf($lang["LOG_$log"],$user)."\r\n");
  @fclose($file);

  return true;
}

function checkuid($uid)
{
  if(time()>substr($uid,13)+uidtimeout) return 0;
  return 1;
}
//date 1.2.2006
function loginuser($user, $password,$method="",$uid="")
{
    global $admin, $integrate, $domain, $mailserver, $dleavemessages, $otherconfig, $LOCAL_ADDR, $REMOTE_ADDR,$pass_expired;

	if (!$user || preg_match('/[<>]/',$user)) return false;

    if ($otherconfig["FULLMERAK"])
    {
      list($fdummy, $username) = explode("/", $user);
      if ($username) $user = $username;

     @include_once('integrateinclude.html');
     @include_once('../integrateinclude.html');

      $result = integrateauthenticateuser($user, $password, $method, $uid);

      if (substr($result, 0, 1) == "*")
      {
        $result = trim(substr($result, 1, strlen($result) - 1));
        $merakadmin = substr($result, 0, 1);
        $result = trim(substr($result, 1, strlen($result) - 1));

        list($merakname, $merakemail) = explode("<", $result);
        $merakname = trim($merakname);
        list($merakemail, $merakpath) = explode(">", $merakemail);
        $merakemail = trim($merakemail);
        $merakpath  = trim($merakpath);

        if (strpos($merakpath, "\n"))
        {
          $items = explode("\n", $merakpath);
          $merakpath = trim($items[0]);
          $userquota = trim($items[1]);
          $ntpassword = trim($items[3]);
          if (!$ntpassword) $password = trim($items[2]);
          $pass_expired = trim($items[4]);
        }

		if (!$merakpath || strpos($merakpath,'|') === 0) return false;

        list($xalias, $merakdomain) = explode("@", $merakemail);
        list($xdomain) = explode(";", $domain);

        if (strcasecmp($xdomain, $merakdomain)) $user = $merakdomain . "/" . $user;

        if (trim($otherconfig["ALLOWEDDOMAINS"]))
        {
          if (!(strpos(";;" . strtolower(trim($otherconfig["ALLOWEDDOMAINS"])) . ";", ";" . strtolower($merakdomain) . ";"))) return false;
        }
      }
      else
        return false;
    }

    $config = getuserconfig($user);

    if (!$config)
    {
      if (!($integrate)) return false;

      $accounts = getaccounts();

      list($fdomain, $username) = explode("/", $user);
      if (!($username)) $username = $user;

      $config["USER"] = $user;
      $config["PASS"] = $password;
      $add = "";
      list($fdomain) = explode(";", $domain);
      if ($fdomain) if (!(strpos($user, "@"))) $add = "@" . $fdomain;
      $config["EMAIL"] = $username . $add;
      if ($merakemail) $config["EMAIL"] = $merakemail;
      $config["FULLNAME"] = $username;
      if ($merakname) $config["FULLNAME"] = $merakname;
      $config["ADMIN"] = false;
      if ($merakadmin) $config["ADMIN"] = $merakadmin;
      $config["HOST"] = $mailserver;
      $config["HOSTUSER"] = $user;
      $config["HOSTPASS"] = $password;
      $config["DELETE"] = !($dleavemessages);
      $config["REPLYTO"] = "";
      $config["FULLHEADER"] = "";
      $config["MULTI"] = "";
      $config["ATTACH"] = "";
      $config["DELETESERVER"] = $otherconfig["DELETEMESSAGES"];
      $config["UIDLDELETE"] = $otherconfig["DELETEDELETED"];
      $config["NOQUOTA"] = "";

      $accounts[] = $config;
      saveaccounts($accounts);
    }
    else{
      // NT Password - For Encrypted Login use old one
      if ($ntpassword && $method) $password = $config["PASS"];

      if ($integrate && ($config["PASS"] <> $password || $config["HOST"] <> $mailserver || $config["HOSTUSER"] <> $user || $config["HOSTPASS"] <> $password || $config["ADMIN"] <> $merakadmin || $config["FULLNAME"] <> $merakname))
      {

        $config["PASS"] = $password;
        $config["HOST"] = $mailserver;
        $config["HOSTUSER"] = $user;
        $config["HOSTPASS"] = $password;

        if ($otherconfig["FULLMERAK"])
        {
          // 2 - Does not inherit admin flag
          if ($config["ADMIN"] <> 2) $config["ADMIN"] = $merakadmin;
          $config["EMAIL"] = $merakemail;
          $config["FULLNAME"] = $merakname;
        }
        saveuserconfig($user, $config);
      }
    }

    $accounts = array();

    if (!$integrate && strcasecmp($config["PASS"], $password)) return false;

    // Session ID
    $id = md5(uniqid(rand()) . $user);

    // Session Directory
    @mkdir(sessiondir, 0750);
    $sessionpath = sessiondir . $id . "/";
    @mkdir($sessionpath, 0750);

    updatesession($id, $user);

    // Previous Session Delete
    $session = @file(usersdir . $user . "/" . sessionfile);
    if (is_array($session))
    {
      @unlink(sessiondir . trim($session[0]) . "/" . sessionfile);
      @rmdir(sessiondir . trim($session[0]));
    }

    // User Directory
    list($fdomain, $username) = explode("/", $user);
    @mkdir(usersdir, 0750);
    if ($username) @mkdir(usersdir . $fdomain, 0750);
    @mkdir(usersdir . $user, 0750);

    // Save Session To Users Dir For Future Delete
    @copy($sessionpath . sessionfile, usersdir . $user . "/" . sessionfile);

    if ($otherconfig["FULLMERAK"] && directmerak && $merakpath)
    {
      unset($calendarenabled,$imenabled);
      pluginsloadstate($config["EMAIL"],$calendarenabled,$imenabled);
      savemailboxpath($id, trim($merakpath), $userquota, $calendarenabled,$imenabled);
    }
    dolog($user,1);
    return $id;
}
?>
